==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/acl_policy_result.py <==
# coding: utf-8

import re
import six





class AclPolicyResult:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'allow_address_netmasks': 'list[AllowAddressNetmasksResult]',
        'allow_ip_ranges': 'list[AllowIpRangesResult]'
    }

    attribute_map = {
        'allow_address_netmasks': 'allow_address_netmasks',
        'allow_ip_ranges': 'allow_ip_ranges'
    }

    def __init__(self, allow_address_netmasks=None, allow_ip_ranges=None):
        """AclPolicyResult - a model defined in huaweicloud sdk"""
        
        

        self._allow_address_netmasks = None
        self._allow_ip_ranges = None
        self.discriminator = None

        self.allow_address_netmasks = allow_address_netmasks
        self.allow_ip_ranges = allow_ip_ranges

    @property
    def allow_address_netmasks(self):
        """Gets the allow_address_netmasks of this AclPolicyResult.

        允许访问的IP地址或网段。

        :return: The allow_address_netmasks of this AclPolicyResult.
        :rtype: list[AllowAddressNetmasksResult]
        """
        return self._allow_address_netmasks

    @allow_address_netmasks.setter
    def allow_address_netmasks(self, allow_address_netmasks):
        """Sets the allow_address_netmasks of this AclPolicyResult.

        允许访问的IP地址或网段。

        :param allow_address_netmasks: The allow_address_netmasks of this AclPolicyResult.
        :type: list[AllowAddressNetmasksResult]
        """
        self._allow_address_netmasks = allow_address_netmasks

    @property
    def allow_ip_ranges(self):
        """Gets the allow_ip_ranges of this AclPolicyResult.

        允许访问的IP地址区间。

        :return: The allow_ip_ranges of this AclPolicyResult.
        :rtype: list[AllowIpRangesResult]
        """
        return self._allow_ip_ranges

    @allow_ip_ranges.setter
    def allow_ip_ranges(self, allow_ip_ranges):
        """Sets the allow_ip_ranges of this AclPolicyResult.

        允许访问的IP地址区间。

        :param allow_ip_ranges: The allow_ip_ranges of this AclPolicyResult.
        :type: list[AllowIpRangesResult]
        """
        self._allow_ip_ranges = allow_ip_ranges

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AclPolicyResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.54-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/acl_policy_result.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AclPolicyResult:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'allow_address_netmasks': 'list[AllowAddressNetmasksResult]',
        'allow_ip_ranges': 'list[AllowIpRangesResult]'
    }

    attribute_map = {
        'allow_address_netmasks': 'allow_address_netmasks',
        'allow_ip_ranges': 'allow_ip_ranges'
    }

    def __init__(self, allow_address_netmasks=None, allow_ip_ranges=None):
        """AclPolicyResult - a model defined in huaweicloud sdk"""
        
        

        self._allow_address_netmasks = None
        self._allow_ip_ranges = None
        self.discriminator = None

        self.allow_address_netmasks = allow_address_netmasks
        self.allow_ip_ranges = allow_ip_ranges

    @property
    def allow_address_netmasks(self):
        """Gets the allow_address_netmasks of this AclPolicyResult.

        允许访问的IP地址或网段。

        :return: The allow_address_netmasks of this AclPolicyResult.
        :rtype: list[AllowAddressNetmasksResult]
        """
        return self._allow_address_netmasks

    @allow_address_netmasks.setter
    def allow_address_netmasks(self, allow_address_netmasks):
        """Sets the allow_address_netmasks of this AclPolicyResult.

        允许访问的IP地址或网段。

        :param allow_address_netmasks: The allow_address_netmasks of this AclPolicyResult.
        :type: list[AllowAddressNetmasksResult]
        """
        self._allow_address_netmasks = allow_address_netmasks

    @property
    def allow_ip_ranges(self):
        """Gets the allow_ip_ranges of this AclPolicyResult.

        允许访问的IP地址区间。

        :return: The allow_ip_ranges of this AclPolicyResult.
        :rtype: list[AllowIpRangesResult]
        """
        return self._allow_ip_ranges

    @allow_ip_ranges.setter
    def allow_ip_ranges(self, allow_ip_ranges):
        """Sets the allow_ip_ranges of this AclPolicyResult.

        允许访问的IP地址区间。

        :param allow_ip_ranges: The allow_ip_ranges of this AclPolicyResult.
        :type: list[AllowIpRangesResult]
        """
        self._allow_ip_ranges = allow_ip_ranges

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AclPolicyResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
